@@ -1,6 +1,6 @@
 import json
 from .util import check_type, unique_string
-
+from datetime import datetime
 
 class classorinstancemethod(classmethod):
 
@@ -27,6 +27,8 @@ class JsonObject:
             s += "\"%s\":" % k
             if isinstance(v[k], str):
                 s += "%s" % json.dumps(v[k])
+            elif isinstance(v[k], datetime):
+                s += "\"%s\"" % str(v[k])
             elif isinstance(v[k], bool):
                 s += "%s" % str(v[k]).lower()
             else:
@@ -186,10 +188,10 @@ class JsonList(list):
         return "[" + ",".join([json.dumps(x) if type(x) is str else str(x) for x in self]) + "]"
 
     def get(self, m):
-        it = type(vars(self.list_type)[m])
-        l = JsonList(list_type=it)
+        l = JsonList()
         for i in self:
-            l.append(vars(i)[m])
+            if m in vars(i):
+                l.append(vars(i)[m])
         return l
 
     def where(self, m, v, o="=="):
